@@ -6,7 +6,8 @@ class SimpleMapTokenizer(object):
         tkn2id
         pad_id
         max_len
-        start_id
+        start_id:
+            If set it will be prepended to each input example
     '''
     def __init__(self, tkn2id, pad_id, max_len=50, start_id=None):
         self.tkn2id = tkn2id
@@ -14,6 +15,7 @@ class SimpleMapTokenizer(object):
         self.max_len = max_len
         self.start_id = start_id
 
+
     def tokens_to_ids(self, tokens):
         out = [self.tkn2id[tkn] for tkn in tokens]
         if self.start_id is not None:
@@ -21,3 +23,9 @@ class SimpleMapTokenizer(object):
         out = out[:self.max_len]
 
         return out
+
+
+    def encode(self, examples):
+        examples['input_ids'] = [self.tokens_to_ids(stream[:-1]) for stream in examples['stream']]
+
+        return examples
