@@ -42,3 +42,17 @@ def get_embeddings_for_tokens(dataset, cdb, context_type='medium', special_token
             embeddings.append(np.zeros(len(embeddings[0])))
 
     return embeddings, tkn2id, id2tkn
+
+
+def stream_to_separate_examples(examples):
+    r''' Convert a stream to separate examples that can be used to train
+    a next concept predictor unable to handle sequences. Use with HF datasets map function.
+
+    '''
+    out = {}
+    out['input_ids'] = [example[0:i+1] for example in examples['input_ids'] for i in range(len(example) - 1)]
+    out['labels'] = [example[i+1] for example in examples['input_ids'] for i in range(len(example) - 1)]
+    out['labels_all'] = [example[i+1:] for example in examples['input_ids'] for i in range(len(example) - 1)]
+    out['patient_id'] = [id for ind, id in enumerate(examples['patient_id']) for _ in range(len(examples['input_ids'][ind]) - 1)]
+
+    return out
